Crate agentsdk

Crate agentsdk 

Re-exports

pub use core::agent::Agent;
pub use core::agent::AgentBuilder;
pub use core::agent::AgentOptions;
pub use core::agent::CompletionAction;
pub use core::agent::LLMBackend;
pub use core::agent::PostToolAction;
pub use core::agent::PreToolAction;
pub use core::hil::HilItem;
pub use core::hil::HilPlugin;
pub use core::hil::HilState;
pub use core::hil::HilType;
pub use core::hil::SelectOption;
pub use core::history::FileHistoryPlugin;
pub use core::history::History;
pub use core::history::MemoryHistoryPlugin;
pub use core::messages;
pub use core::messages::Messages;
pub use core::plugin::AgentPlugin;
pub use core::plugin::PluginContext;
pub use core::plugin::PluginToolCall;
pub use core::plugin::PluginTools;
pub use core::retry::RetryAction;
pub use core::tools::Tool;
pub use core::tools::ToolContext;
pub use core::tools::ToolDefinition;
pub use error::AgentSdkError;
pub use error::Result;
pub use openai::ModelConfig;
pub use openai::OpenAI;

Modules

__private
core
error
openai

Enums

Message

Attribute Macros

tool
Constructs a tool from a function defnition. A tool has a name, a description, an input and a body. all three components are infered from a standard rust function. The name is the defined name of the function, The description is infered from the doc comments of the function, The input infered from the function arguments.

Derive Macros

PluginTools
Derives PluginTools for an enum.